summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--themes/danix-xyz-hacker/assets/js/tag-cloud-spiral.js7
1 files changed, 4 insertions, 3 deletions
diff --git a/themes/danix-xyz-hacker/assets/js/tag-cloud-spiral.js b/themes/danix-xyz-hacker/assets/js/tag-cloud-spiral.js
index 6965565..9f8b7b4 100644
--- a/themes/danix-xyz-hacker/assets/js/tag-cloud-spiral.js
+++ b/themes/danix-xyz-hacker/assets/js/tag-cloud-spiral.js
@@ -44,9 +44,10 @@ document.addEventListener('DOMContentLoaded', function () {
return { w: rect.width, h: rect.height };
});
// Switch container to relative positioning
container.style.position = 'relative';
container.style.display = 'block';
+ container.classList.remove('flex', 'flex-wrap');
var padding = 8; // px gap between tags
var aStep = 0.3; // radians per spiral step
@@ -115,7 +116,7 @@ document.addEventListener('DOMContentLoaded', function () {
}
});
- // Set container height to fit all tags + 2rem bottom padding
- container.style.height = (maxBottom - minTop + 48) + 'px';
+ // Set container height to fit all tags + 2rem bottom padding (32px)
+ container.style.height = (maxBottom - minTop + 32) + 'px';
});
});
@@ -44,9 +44,10 @@ document.addEventListener('DOMContentLoaded', function () {
return { w: rect.width, h: rect.height };
});
- // Switch container to relative positioning
+ // Switch container to relative positioning and remove flex layout
container.style.position = 'relative';
container.style.display = 'block';